import re

import inflect
from django.contrib import admin
from django.urls import reverse
from django.utils.html import format_html
from django.utils.translation import gettext_lazy as _
from django_audit_fields.admin import audit_fieldset_tuple
from edc_constants.constants import COMPLETE, NEW, NOT_APPLICABLE, UUID_PATTERN
from edc_model_admin.mixins import ModelAdminRedirectAllToChangelistMixin
from edc_sites.admin import SiteModelAdminMixin
from intecomm_form_validators import RECRUITING
from intecomm_rando.constants import COMMUNITY_ARM

from intecomm_screening.admin.modeladmin_mixins import BaseModelAdminMixin

from ..admin_site import intecomm_group_admin
from ..exceptions import PatientGroupNotRandomized
from ..forms import PatientGroupForm
from ..models import PatientGroup
from ..utils import (
    get_assignment_description_for_patient_group,
    get_group_subject_dashboards_url,
)

p = inflect.engine()


@admin.register(PatientGroup, site=intecomm_group_admin)
class PatientGroupAdmin(
    SiteModelAdminMixin, ModelAdminRedirectAllToChangelistMixin, BaseModelAdminMixin
):

    """Modeladmin for patient groups in follow-up or dissolved.

    See `get_queryset`"""

    form = PatientGroupForm

    show_object_tools = True
    change_list_template: str = "intecomm_group/admin/patientgroup_change_list.html"
    show_save_next = False
    show_cancel = True

    changelist_url = "intecomm_group_admin:intecomm_group_patientgroup_changelist"
    change_search_field_name = "group_identifier"
    add_search_field_name = "group_identifier"

    fieldsets = (
        (
            None,
            {"fields": ("report_datetime", "name", "status", "notes")},
        ),
        audit_fieldset_tuple,
    )

    list_display = (
        "__str__",
        "to_subjects",
        "arm",
        "meetings",
        "group_id",
        "randomized_date",
        "opened",
        "user_created",
        "created",
    )

    list_filter = (
        "status",
        "randomized",
        "report_datetime",
        "randomized_datetime",
    )

    search_fields = (
        "name",
        "group_identifier",
        "patients__legal_name__exact",
        "patients__familiar_name__exact",
        "patients__initials__iexact",
    )

    radio_fields = {
        "status": admin.VERTICAL,
    }

    readonly_fields = (
        "report_datetime",
        "name",
        "status",
        "randomized",
        "randomized_datetime",
    )

    @admin.display(description="Randomized", ordering="randomized_datetime")
    def randomized_date(self, obj=None):
        try:
            return obj.randomized_datetime.date()
        except AttributeError:
            return None

    @admin.display(description="Status", ordering="status")
    def group_status(self, obj):
        return format_html(f'<span class="nowrap">{obj.get_status_display()}</span>')

    @admin.display(description="Group identifier", ordering="group_identifier")
    def group_id(self, obj):
        return (
            None if re.match(UUID_PATTERN, str(obj.group_identifier)) else obj.group_identifier
        )

    @admin.display(description="Opened", ordering="report_datetime")
    def opened(self, obj=None):
        return obj.report_datetime.date()

    @admin.display(description="Randomization")
    def arm(self, obj=None):
        try:
            arm_as_str = get_assignment_description_for_patient_group(obj.group_identifier)
        except PatientGroupNotRandomized:
            link = None
        else:
            url = reverse(
                "intecomm_screening_admin:intecomm_screening_patientgroup_changelist"
            )
            url = f"{url}?q={obj.name}"
            link = format_html(
                f'<a title="Back to ALL patient groups" href="{url}">{arm_as_str}</a>'
            )
        return link

    @admin.display(description="Meetings")
    def meetings(self, obj=None) -> str:
        url = NOT_APPLICABLE
        try:
            arm_as_str = get_assignment_description_for_patient_group(obj.group_identifier)
        except PatientGroupNotRandomized:
            pass
        else:
            if arm_as_str == COMMUNITY_ARM:
                name = "+".join(obj.name.split(" "))
                url = reverse(
                    "intecomm_group_admin:intecomm_group_patientgroupmeeting_changelist"
                )
                url = f"{url}?q={name}"
                url = format_html(f'<a href="{url}">Meetings</a>')
        return url

    @admin.display(description="Dashboards")
    def to_subjects(self, obj=None):
        cnt = obj.patients.all().count()
        url = get_group_subject_dashboards_url(obj)
        title = _("Go to subject dashboards")
        return format_html(
            f'<a title="{title}" href="{url}">'
            f'<span class="nowrap">{cnt}&nbsp;{p.plural("subject", cnt)}</span></a>'
        )

    def get_queryset(self, request):
        return (
            super()
            .get_queryset(request)
            .exclude(status__in=[NEW, RECRUITING, COMPLETE], randomized=False)
        )



# Generated by Django 4.1.7 on 2023-04-03 17:25

from django.db import migrations, models
import edc_model.validators.date


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0017_alter_bloodresultsfbc_results_abnormal_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicalhivinitialreview",
            name="vl_date",
        ),
        migrations.RemoveField(
            model_name="hivinitialreview",
            name="vl_date",
        ),
        migrations.AddField(
            model_name="historicalhivinitialreview",
            name="drawn_date",
            field=models.DateField(
                blank=True,
                help_text="If exact date not known, please estimate",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date specimen drawn",
            ),
        ),
        migrations.AddField(
            model_name="hivinitialreview",
            name="drawn_date",
            field=models.DateField(
                blank=True,
                help_text="If exact date not known, please estimate",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date specimen drawn",
            ),
        ),
        migrations.AlterField(
            model_name="dminitialreview",
            name="glucose_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=10,
                verbose_name="Glucose quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="dmreview",
            name="glucose_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=10,
                verbose_name="Glucose quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="glucose_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=10,
                verbose_name="Glucose quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldminitialreview",
            name="glucose_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=10,
                verbose_name="Glucose quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldmreview",
            name="glucose_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=10,
                verbose_name="Glucose quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="glucose_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=10,
                verbose_name="Glucose quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhivinitialreview",
            name="arv_initiation_actual_date",
            field=models.DateField(
                blank=True,
                help_text="If possible, provide the exact date here instead of estimating above.",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date started antiretroviral therapy (ART)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhivinitialreview",
            name="vl_quantifier",
            field=models.CharField(
                choices=[
                    ("N/A", "Not applicable"),
                    ("=", "="),
                    (">", ">"),
                    ("<", "<"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=10,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalviralloadresult",
            name="vl_quantifier",
            field=models.CharField(
                choices=[
                    ("N/A", "Not applicable"),
                    ("=", "="),
                    (">", ">"),
                    ("<", "<"),
                    ("N/A", "Not applicable"),
                ],
                default="=",
                max_length=10,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicalvitals",
            name="comments",
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="hivinitialreview",
            name="arv_initiation_actual_date",
            field=models.DateField(
                blank=True,
                help_text="If possible, provide the exact date here instead of estimating above.",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date started antiretroviral therapy (ART)",
            ),
        ),
        migrations.AlterField(
            model_name="hivinitialreview",
            name="vl_quantifier",
            field=models.CharField(
                choices=[
                    ("N/A", "Not applicable"),
                    ("=", "="),
                    (">", ">"),
                    ("<", "<"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=10,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="viralloadresult",
            name="vl_quantifier",
            field=models.CharField(
                choices=[
                    ("N/A", "Not applicable"),
                    ("=", "="),
                    (">", ">"),
                    ("<", "<"),
                    ("N/A", "Not applicable"),
                ],
                default="=",
                max_length=10,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="vitals",
            name="comments",
            field=models.TextField(blank=True, null=True),
        ),
    ]



# Generated by Django 4.2.7 on 2023-12-04 14:56

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_lists", "0008_medicationshortagereasons"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="arvdrugs",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Arv Drugs",
                "verbose_name_plural": "Arv Drugs",
            },
        ),
        migrations.AlterModelOptions(
            name="arvregimens",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "ARV Regimens",
                "verbose_name_plural": "ARV Regimens",
            },
        ),
        migrations.AlterModelOptions(
            name="clinicalwithdrawalreasons",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Clinical Withdrawal Reasons",
                "verbose_name_plural": "Clinical Withdrawal Reasons",
            },
        ),
        migrations.AlterModelOptions(
            name="clinicservices",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Clinic Services",
                "verbose_name_plural": "Clinic Services",
            },
        ),
        migrations.AlterModelOptions(
            name="conditions",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Conditions",
                "verbose_name_plural": "Conditions",
            },
        ),
        migrations.AlterModelOptions(
            name="consentrefusalreasons",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Consent Refusal Reasons",
                "verbose_name_plural": "Consent Refusal Reasons",
            },
        ),
        migrations.AlterModelOptions(
            name="dmmanagement",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Diabetes Management",
                "verbose_name_plural": "Diabetes Management",
            },
        ),
        migrations.AlterModelOptions(
            name="dmtreatments",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Diabetes Treatments",
                "verbose_name_plural": "Diabetes Treatments",
            },
        ),
        migrations.AlterModelOptions(
            name="drugdispensaries",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Drug Dispensaries",
                "verbose_name_plural": "Drug Dispensaries",
            },
        ),
        migrations.AlterModelOptions(
            name="drugdispensers",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Drug Dispensers",
                "verbose_name_plural": "Drug Dispensers",
            },
        ),
        migrations.AlterModelOptions(
            name="drugpaysources",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Drug Payment Sources",
                "verbose_name_plural": "Drug Payment Sources",
            },
        ),
        migrations.AlterModelOptions(
            name="healthadvisors",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Health Advisors",
                "verbose_name_plural": "Health Advisors",
            },
        ),
        migrations.AlterModelOptions(
            name="healthfacilitytypes",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Health Facility Type",
                "verbose_name_plural": "Health Facility Types",
            },
        ),
        migrations.AlterModelOptions(
            name="healthinterventiontypes",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Health Intervention Types",
                "verbose_name_plural": "Health Intervention Types",
            },
        ),
        migrations.AlterModelOptions(
            name="healthservices",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Health Services",
                "verbose_name_plural": "Health Services",
            },
        ),
        migrations.AlterModelOptions(
            name="healthtalkconditions",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Health Talk Conditions",
                "verbose_name_plural": "Health Talk Conditions",
            },
        ),
        migrations.AlterModelOptions(
            name="healthtalktypes",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Health Talk Type",
                "verbose_name_plural": "Health Talk Types",
            },
        ),
        migrations.AlterModelOptions(
            name="htnmanagement",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "HTN Management",
                "verbose_name_plural": "HTN Management",
            },
        ),
        migrations.AlterModelOptions(
            name="htntreatments",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Hypertension Treatments",
                "verbose_name_plural": "Hypertension Treatments",
            },
        ),
        migrations.AlterModelOptions(
            name="laboratorytests",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Laboratory Tests",
                "verbose_name_plural": "Laboratory Tests",
            },
        ),
        migrations.AlterModelOptions(
            name="locationtypes",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Community-care location type",
                "verbose_name_plural": "Community-care location types",
            },
        ),
        migrations.AlterModelOptions(
            name="medicationshortagereasons",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Medication shortage reasons",
                "verbose_name_plural": "Medication shortage reasons",
            },
        ),
        migrations.AlterModelOptions(
            name="nonadherencereasons",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "NonAdherence Reasons",
                "verbose_name_plural": "NonAdherence Reasons",
            },
        ),
        migrations.AlterModelOptions(
            name="offstudyreasons",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Offstudy Reasons",
                "verbose_name_plural": "Offstudy Reasons",
            },
        ),
        migrations.AlterModelOptions(
            name="refillconditions",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Refill Conditions",
                "verbose_name_plural": "Refill Conditions",
            },
        ),
        migrations.AlterModelOptions(
            name="rxmodificationreasons",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Treatment Modification Reasons",
                "verbose_name_plural": "Treatment Modification Reasons",
            },
        ),
        migrations.AlterModelOptions(
            name="rxmodifications",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Treatment Modifications",
                "verbose_name_plural": "Treatment Modifications",
            },
        ),
        migrations.AlterModelOptions(
            name="screeningrefusalreasons",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Screening Refusal Reasons",
                "verbose_name_plural": "Screening Refusal Reasons",
            },
        ),
        migrations.AlterModelOptions(
            name="subjectvisitmissedreasons",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Subject Missed Visit Reasons",
                "verbose_name_plural": "Subject Missed Visit Reasons",
            },
        ),
        migrations.AlterModelOptions(
            name="toxicitywithdrawalreasons",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Toxicity Withdrawal Reasons",
                "verbose_name_plural": "Toxicity Withdrawal Reasons",
            },
        ),
        migrations.AlterModelOptions(
            name="transferreasons",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Transfer Reasons",
                "verbose_name_plural": "Transfer Reasons",
            },
        ),
        migrations.AlterModelOptions(
            name="transportchoices",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Transport Choices",
                "verbose_name_plural": "Transport Choices",
            },
        ),
        migrations.AlterModelOptions(
            name="visitreasons",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Visit Reasons",
                "verbose_name_plural": "Visit Reasons",
            },
        ),
        migrations.RemoveIndex(
            model_name="arvdrugs",
            name="intecomm_li_id_82a046_idx",
        ),
        migrations.RemoveIndex(
            model_name="arvregimens",
            name="intecomm_li_id_963095_idx",
        ),
        migrations.RemoveIndex(
            model_name="clinicalwithdrawalreasons",
            name="intecomm_li_id_33f6f1_idx",
        ),
        migrations.RemoveIndex(
            model_name="clinicservices",
            name="intecomm_li_id_97c7c2_idx",
        ),
        migrations.RemoveIndex(
            model_name="conditions",
            name="intecomm_li_id_a3d457_idx",
        ),
        migrations.RemoveIndex(
            model_name="consentrefusalreasons",
            name="intecomm_li_id_3f4631_idx",
        ),
        migrations.RemoveIndex(
            model_name="dmmanagement",
            name="intecomm_li_id_b4d41f_idx",
        ),
        migrations.RemoveIndex(
            model_name="dmtreatments",
            name="intecomm_li_id_aa0a3b_idx",
        ),
        migrations.RemoveIndex(
            model_name="drugdispensaries",
            name="intecomm_li_id_ffb6be_idx",
        ),
        migrations.RemoveIndex(
            model_name="drugdispensers",
            name="intecomm_li_id_cc5dec_idx",
        ),
        migrations.RemoveIndex(
            model_name="drugpaysources",
            name="intecomm_li_id_27e420_idx",
        ),
        migrations.RemoveIndex(
            model_name="healthadvisors",
            name="intecomm_li_id_ffdb67_idx",
        ),
        migrations.RemoveIndex(
            model_name="healthfacilitytypes",
            name="intecomm_li_id_727813_idx",
        ),
        migrations.RemoveIndex(
            model_name="healthinterventiontypes",
            name="intecomm_li_id_9b4020_idx",
        ),
        migrations.RemoveIndex(
            model_name="healthservices",
            name="intecomm_li_id_1604f4_idx",
        ),
        migrations.RemoveIndex(
            model_name="healthtalkconditions",
            name="intecomm_li_id_21baf0_idx",
        ),
        migrations.RemoveIndex(
            model_name="healthtalktypes",
            name="intecomm_li_id_5f9413_idx",
        ),
        migrations.RemoveIndex(
            model_name="htnmanagement",
            name="intecomm_li_id_91f6e0_idx",
        ),
        migrations.RemoveIndex(
            model_name="htntreatments",
            name="intecomm_li_id_ce0438_idx",
        ),
        migrations.RemoveIndex(
            model_name="laboratorytests",
            name="intecomm_li_id_b0664c_idx",
        ),
        migrations.RemoveIndex(
            model_name="locationtypes",
            name="intecomm_li_id_8c336e_idx",
        ),
        migrations.RemoveIndex(
            model_name="medicationshortagereasons",
            name="intecomm_li_id_50cc4d_idx",
        ),
        migrations.RemoveIndex(
            model_name="nonadherencereasons",
            name="intecomm_li_id_31cb50_idx",
        ),
        migrations.RemoveIndex(
            model_name="offstudyreasons",
            name="intecomm_li_id_c1b6d2_idx",
        ),
        migrations.RemoveIndex(
            model_name="refillconditions",
            name="intecomm_li_id_17855a_idx",
        ),
        migrations.RemoveIndex(
            model_name="rxmodificationreasons",
            name="intecomm_li_id_c4f7bb_idx",
        ),
        migrations.RemoveIndex(
            model_name="rxmodifications",
            name="intecomm_li_id_4fd810_idx",
        ),
        migrations.RemoveIndex(
            model_name="screeningrefusalreasons",
            name="intecomm_li_id_3c9136_idx",
        ),
        migrations.RemoveIndex(
            model_name="subjectvisitmissedreasons",
            name="intecomm_li_id_6fb3a6_idx",
        ),
        migrations.RemoveIndex(
            model_name="toxicitywithdrawalreasons",
            name="intecomm_li_id_710a9d_idx",
        ),
        migrations.RemoveIndex(
            model_name="transferreasons",
            name="intecomm_li_id_58872e_idx",
        ),
        migrations.RemoveIndex(
            model_name="transportchoices",
            name="intecomm_li_id_8a0a27_idx",
        ),
        migrations.RemoveIndex(
            model_name="visitreasons",
            name="intecomm_li_id_1dbf9b_idx",
        ),
        migrations.AlterField(
            model_name="arvdrugs",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="arvdrugs",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="arvdrugs",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="arvregimens",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="arvregimens",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="arvregimens",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="clinicalwithdrawalreasons",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="clinicalwithdrawalreasons",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="clinicalwithdrawalreasons",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="clinicservices",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="clinicservices",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="clinicservices",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="conditions",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="conditions",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="conditions",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="consentrefusalreasons",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="consentrefusalreasons",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="consentrefusalreasons",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="dmmanagement",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="dmmanagement",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="dmmanagement",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="dmtreatments",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="dmtreatments",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="dmtreatments",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="drugdispensaries",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="drugdispensaries",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="drugdispensaries",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="drugdispensers",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="drugdispensers",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="drugdispensers",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="drugpaysources",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="drugpaysources",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="drugpaysources",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="healthadvisors",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="healthadvisors",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="healthadvisors",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="healthfacilitytypes",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="healthfacilitytypes",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="healthfacilitytypes",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="healthinterventiontypes",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="healthinterventiontypes",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="healthinterventiontypes",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="healthservices",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="healthservices",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="healthservices",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="healthtalkconditions",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="healthtalkconditions",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="healthtalkconditions",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="healthtalktypes",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="healthtalktypes",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="healthtalktypes",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="htnmanagement",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="htnmanagement",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="htnmanagement",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="htntreatments",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="htntreatments",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="htntreatments",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="laboratorytests",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="laboratorytests",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="laboratorytests",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="locationtypes",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="locationtypes",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="locationtypes",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="medicationshortagereasons",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="medicationshortagereasons",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="medicationshortagereasons",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="nonadherencereasons",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="nonadherencereasons",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="nonadherencereasons",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="offstudyreasons",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="offstudyreasons",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="offstudyreasons",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="refillconditions",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="refillconditions",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="refillconditions",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="rxmodificationreasons",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="rxmodificationreasons",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="rxmodificationreasons",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="rxmodifications",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="rxmodifications",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="rxmodifications",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="screeningrefusalreasons",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="screeningrefusalreasons",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="screeningrefusalreasons",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissedreasons",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissedreasons",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissedreasons",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="toxicitywithdrawalreasons",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="toxicitywithdrawalreasons",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="toxicitywithdrawalreasons",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="transferreasons",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="transferreasons",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="transferreasons",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="transportchoices",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="transportchoices",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="transportchoices",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="visitreasons",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="visitreasons",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="visitreasons",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AddIndex(
            model_name="arvdrugs",
            index=models.Index(fields=["name"], name="intecomm_li_name_b55bdc_idx"),
        ),
        migrations.AddIndex(
            model_name="arvdrugs",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_6fd0a7_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="arvregimens",
            index=models.Index(fields=["name"], name="intecomm_li_name_dd4128_idx"),
        ),
        migrations.AddIndex(
            model_name="arvregimens",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_109d17_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="clinicalwithdrawalreasons",
            index=models.Index(fields=["name"], name="intecomm_li_name_bfca7f_idx"),
        ),
        migrations.AddIndex(
            model_name="clinicalwithdrawalreasons",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_23f821_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="clinicservices",
            index=models.Index(fields=["name"], name="intecomm_li_name_deec16_idx"),
        ),
        migrations.AddIndex(
            model_name="clinicservices",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_ed922c_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="conditions",
            index=models.Index(fields=["name"], name="intecomm_li_name_b9ae61_idx"),
        ),
        migrations.AddIndex(
            model_name="conditions",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_7a1347_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="consentrefusalreasons",
            index=models.Index(fields=["name"], name="intecomm_li_name_04461e_idx"),
        ),
        migrations.AddIndex(
            model_name="consentrefusalreasons",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_c72ae6_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="dmmanagement",
            index=models.Index(fields=["name"], name="intecomm_li_name_edefb8_idx"),
        ),
        migrations.AddIndex(
            model_name="dmmanagement",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_a3448c_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="dmtreatments",
            index=models.Index(fields=["name"], name="intecomm_li_name_596944_idx"),
        ),
        migrations.AddIndex(
            model_name="dmtreatments",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_5e34e8_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="drugdispensaries",
            index=models.Index(fields=["name"], name="intecomm_li_name_2312cd_idx"),
        ),
        migrations.AddIndex(
            model_name="drugdispensaries",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_41855f_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="drugdispensers",
            index=models.Index(fields=["name"], name="intecomm_li_name_4d9885_idx"),
        ),
        migrations.AddIndex(
            model_name="drugdispensers",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_31917d_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="drugpaysources",
            index=models.Index(fields=["name"], name="intecomm_li_name_b764fd_idx"),
        ),
        migrations.AddIndex(
            model_name="drugpaysources",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_27e119_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="healthadvisors",
            index=models.Index(fields=["name"], name="intecomm_li_name_dd5fb2_idx"),
        ),
        migrations.AddIndex(
            model_name="healthadvisors",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_d0813b_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="healthfacilitytypes",
            index=models.Index(fields=["name"], name="intecomm_li_name_af9934_idx"),
        ),
        migrations.AddIndex(
            model_name="healthfacilitytypes",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_d3d5f9_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="healthinterventiontypes",
            index=models.Index(fields=["name"], name="intecomm_li_name_5a8bd1_idx"),
        ),
        migrations.AddIndex(
            model_name="healthinterventiontypes",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_7bf3e3_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="healthservices",
            index=models.Index(fields=["name"], name="intecomm_li_name_b9dd17_idx"),
        ),
        migrations.AddIndex(
            model_name="healthservices",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_b2eff6_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="healthtalkconditions",
            index=models.Index(fields=["name"], name="intecomm_li_name_9d805e_idx"),
        ),
        migrations.AddIndex(
            model_name="healthtalkconditions",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_a5c489_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="healthtalktypes",
            index=models.Index(fields=["name"], name="intecomm_li_name_dae47f_idx"),
        ),
        migrations.AddIndex(
            model_name="healthtalktypes",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_c68c32_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="htnmanagement",
            index=models.Index(fields=["name"], name="intecomm_li_name_17a894_idx"),
        ),
        migrations.AddIndex(
            model_name="htnmanagement",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_975a4f_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="htntreatments",
            index=models.Index(fields=["name"], name="intecomm_li_name_ebbf62_idx"),
        ),
        migrations.AddIndex(
            model_name="htntreatments",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_66b578_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="laboratorytests",
            index=models.Index(fields=["name"], name="intecomm_li_name_3dad94_idx"),
        ),
        migrations.AddIndex(
            model_name="laboratorytests",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_64caa0_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="locationtypes",
            index=models.Index(fields=["name"], name="intecomm_li_name_f97934_idx"),
        ),
        migrations.AddIndex(
            model_name="locationtypes",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_a20bbc_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="medicationshortagereasons",
            index=models.Index(fields=["name"], name="intecomm_li_name_ad571f_idx"),
        ),
        migrations.AddIndex(
            model_name="medicationshortagereasons",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_99567a_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="nonadherencereasons",
            index=models.Index(fields=["name"], name="intecomm_li_name_a7a6a5_idx"),
        ),
        migrations.AddIndex(
            model_name="nonadherencereasons",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_6edd6e_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="offstudyreasons",
            index=models.Index(fields=["name"], name="intecomm_li_name_aabb4d_idx"),
        ),
        migrations.AddIndex(
            model_name="offstudyreasons",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_676026_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="refillconditions",
            index=models.Index(fields=["name"], name="intecomm_li_name_085d7f_idx"),
        ),
        migrations.AddIndex(
            model_name="refillconditions",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_041362_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="rxmodificationreasons",
            index=models.Index(fields=["name"], name="intecomm_li_name_c1233d_idx"),
        ),
        migrations.AddIndex(
            model_name="rxmodificationreasons",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_f59fe7_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="rxmodifications",
            index=models.Index(fields=["name"], name="intecomm_li_name_3f4bd2_idx"),
        ),
        migrations.AddIndex(
            model_name="rxmodifications",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_8ee785_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="screeningrefusalreasons",
            index=models.Index(fields=["name"], name="intecomm_li_name_1da54a_idx"),
        ),
        migrations.AddIndex(
            model_name="screeningrefusalreasons",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_a4540f_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="subjectvisitmissedreasons",
            index=models.Index(fields=["name"], name="intecomm_li_name_12d94d_idx"),
        ),
        migrations.AddIndex(
            model_name="subjectvisitmissedreasons",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_11b10d_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="toxicitywithdrawalreasons",
            index=models.Index(fields=["name"], name="intecomm_li_name_30f17d_idx"),
        ),
        migrations.AddIndex(
            model_name="toxicitywithdrawalreasons",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_54eafe_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="transferreasons",
            index=models.Index(fields=["name"], name="intecomm_li_name_eb67c1_idx"),
        ),
        migrations.AddIndex(
            model_name="transferreasons",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_852f8a_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="transportchoices",
            index=models.Index(fields=["name"], name="intecomm_li_name_bea030_idx"),
        ),
        migrations.AddIndex(
            model_name="transportchoices",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_726107_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="visitreasons",
            index=models.Index(fields=["name"], name="intecomm_li_name_59f9c6_idx"),
        ),
        migrations.AddIndex(
            model_name="visitreasons",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_0b9635_idx",
            ),
        ),
    ]



from edc_action_item import site_action_items
from edc_action_item.site_action_items import AlreadyRegistered
from edc_visit_tracking.action_items import MissedVisitAction as BaseMissedVisitAction


# TODO: review if this is needed
class MissedVisitAction(BaseMissedVisitAction):
    reference_model = "intecomm_subject.subjectvisitmissed"
    admin_site_name: str = "intecomm_subject_admin"
    show_on_dashboard = False

    def is_ltfu(self) -> bool:
        return False


def register_actions():
    try:
        site_action_items.register(MissedVisitAction)
    except AlreadyRegistered:
        pass


register_actions()



from django.contrib import admin
from edc_model_admin.mixins import InlineHideOriginalObjectNameMixin, TabularInlineMixin
from edc_rx.modeladmin_mixins import DrugRefillAdminMixin, DrugSupplyInlineMixin

from ..admin_site import intecomm_subject_admin
from ..forms import DrugRefillDmForm, DrugSupplyDmForm
from ..models import DrugRefillDm, DrugSupplyDm
from .modeladmin_mixins import CrfModelAdmin


class DrugSupplyDmInline(
    DrugSupplyInlineMixin,
    TabularInlineMixin,
    admin.TabularInline,
):
    model = DrugSupplyDm
    form = DrugSupplyDmForm


@admin.register(DrugRefillDm, site=intecomm_subject_admin)
class DrugRefillDmAdmin(
    DrugRefillAdminMixin,
    InlineHideOriginalObjectNameMixin,
    CrfModelAdmin,
):
    form = DrugRefillDmForm
    inlines = [DrugSupplyDmInline]



# Generated by Django 4.2.7 on 2023-11-29 20:50

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0127_alter_historicalsubjectvisitmissed_appt_date_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicalsubjectvisit",
            name="clinic_services_other",
        ),
        migrations.RemoveField(
            model_name="subjectvisit",
            name="clinic_services",
        ),
        migrations.RemoveField(
            model_name="subjectvisit",
            name="clinic_services_other",
        ),
        migrations.RemoveField(
            model_name="subjectvisit",
            name="health_services",
        ),
    ]



# Generated by Django 4.2.3 on 2023-08-07 22:12

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_subject",
            "0090_alter_healtheconomicshouseholdhead_hoh_age_and_more",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="healtheconomicsassets",
            name="solar_panels",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Solar panels",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomicsassets",
            name="solar_panels",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Solar panels",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="bicycle",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Bicycle",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="car",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Car",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="computer",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Computer",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="dala_dala",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Dala Dala",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="eaves",
            field=models.CharField(
                default="QUESTION_RETIRED",
                max_length=25,
                verbose_name="Are the eaves open, partially or fully closed?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="fridge",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Fridge",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="generator",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Generator",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="iron",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Flat iron",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="large_livestock",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Large Livestock (e.g. cows, bulls, other cattle, horses, donkeys)",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="lighting_source",
            field=models.CharField(
                choices=[
                    ("1", "Electricity"),
                    ("2", "Paraffin, kerosene or gas lantern "),
                    ("3", "Firewood"),
                    ("4", "Candle"),
                    ("OTHER", "Other, specify ..."),
                ],
                max_length=25,
                verbose_name="What is the main source of lighting?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="mobile_phone",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Mobile phone",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="motorboat",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Boat with a motor",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="motorcycle",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Motorcycle/scooter (PikiPiki/Boda Boda)",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="radio",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Radio",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="shop",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="A business or shop",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="small_animals",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Small animals (goats, sheep, chickens or other poultry, etc)",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="telephone",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Non-mobile telephone",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="television",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Television",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="window_screen_type",
            field=models.CharField(
                default="QUESTION_RETIRED",
                max_length=25,
                verbose_name="Type of screening on external windows",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="window_screens",
            field=models.CharField(
                default="QUESTION_RETIRED",
                max_length=25,
                verbose_name="What is the main screening material of external windows?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="bicycle",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Bicycle",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="car",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Car",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="computer",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Computer",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="dala_dala",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Dala Dala",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="eaves",
            field=models.CharField(
                default="QUESTION_RETIRED",
                max_length=25,
                verbose_name="Are the eaves open, partially or fully closed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="fridge",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Fridge",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="generator",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Generator",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="iron",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Flat iron",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="large_livestock",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Large Livestock (e.g. cows, bulls, other cattle, horses, donkeys)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="lighting_source",
            field=models.CharField(
                choices=[
                    ("1", "Electricity"),
                    ("2", "Paraffin, kerosene or gas lantern "),
                    ("3", "Firewood"),
                    ("4", "Candle"),
                    ("OTHER", "Other, specify ..."),
                ],
                max_length=25,
                verbose_name="What is the main source of lighting?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="mobile_phone",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Mobile phone",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="motorboat",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Boat with a motor",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="motorcycle",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Motorcycle/scooter (PikiPiki/Boda Boda)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="radio",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Radio",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="shop",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="A business or shop",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="small_animals",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Small animals (goats, sheep, chickens or other poultry, etc)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="telephone",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Non-mobile telephone",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="television",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Television",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="window_screen_type",
            field=models.CharField(
                default="QUESTION_RETIRED",
                max_length=25,
                verbose_name="Type of screening on external windows",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="window_screens",
            field=models.CharField(
                default="QUESTION_RETIRED",
                max_length=25,
                verbose_name="What is the main screening material of external windows?",
            ),
        ),
    ]



# Generated by Django 4.2.4 on 2023-08-16 21:13

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_lists", "0008_medicationshortagereasons"),
        ("intecomm_subject", "0104_historicallocationupdate_locationupdate"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="historicallocationupdate",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Location update",
                "verbose_name_plural": "historical Location updates",
            },
        ),
        migrations.AlterModelOptions(
            name="locationupdate",
            options={
                "default_manager_name": "objects",
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Location update",
                "verbose_name_plural": "Location updates",
            },
        ),
        migrations.AddField(
            model_name="dmmedicationadherence",
            name="meds_missed_in_days",
            field=models.IntegerField(
                blank=True,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(180),
                ],
                verbose_name="Since we last saw you, for how many days did you miss taking your medication",
            ),
        ),
        migrations.AddField(
            model_name="dmmedicationadherence",
            name="meds_shortage_in_days",
            field=models.IntegerField(
                blank=True,
                help_text="That is, your supply of medication was finished",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(180),
                ],
                verbose_name="Since we last saw you, for how many days did you NOT HAVE medication to take",
            ),
        ),
        migrations.AddField(
            model_name="dmmedicationadherence",
            name="meds_shortage_reason",
            field=models.ManyToManyField(
                blank=True,
                to="intecomm_lists.medicationshortagereasons",
                verbose_name="Reasons for not having medications (supply/shortage)",
            ),
        ),
        migrations.AddField(
            model_name="historicaldmmedicationadherence",
            name="meds_missed_in_days",
            field=models.IntegerField(
                blank=True,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(180),
                ],
                verbose_name="Since we last saw you, for how many days did you miss taking your medication",
            ),
        ),
        migrations.AddField(
            model_name="historicaldmmedicationadherence",
            name="meds_shortage_in_days",
            field=models.IntegerField(
                blank=True,
                help_text="That is, your supply of medication was finished",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(180),
                ],
                verbose_name="Since we last saw you, for how many days did you NOT HAVE medication to take",
            ),
        ),
        migrations.AddField(
            model_name="historicalhivmedicationadherence",
            name="meds_missed_in_days",
            field=models.IntegerField(
                blank=True,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(180),
                ],
                verbose_name="Since we last saw you, for how many days did you miss taking your medication",
            ),
        ),
        migrations.AddField(
            model_name="historicalhivmedicationadherence",
            name="meds_shortage_in_days",
            field=models.IntegerField(
                blank=True,
                help_text="That is, your supply of medication was finished",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(180),
                ],
                verbose_name="Since we last saw you, for how many days did you NOT HAVE medication to take",
            ),
        ),
        migrations.AddField(
            model_name="historicalhtnmedicationadherence",
            name="meds_missed_in_days",
            field=models.IntegerField(
                blank=True,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(180),
                ],
                verbose_name="Since we last saw you, for how many days did you miss taking your medication",
            ),
        ),
        migrations.AddField(
            model_name="historicalhtnmedicationadherence",
            name="meds_shortage_in_days",
            field=models.IntegerField(
                blank=True,
                help_text="That is, your supply of medication was finished",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(180),
                ],
                verbose_name="Since we last saw you, for how many days did you NOT HAVE medication to take",
            ),
        ),
        migrations.AddField(
            model_name="hivmedicationadherence",
            name="meds_missed_in_days",
            field=models.IntegerField(
                blank=True,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(180),
                ],
                verbose_name="Since we last saw you, for how many days did you miss taking your medication",
            ),
        ),
        migrations.AddField(
            model_name="hivmedicationadherence",
            name="meds_shortage_in_days",
            field=models.IntegerField(
                blank=True,
                help_text="That is, your supply of medication was finished",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(180),
                ],
                verbose_name="Since we last saw you, for how many days did you NOT HAVE medication to take",
            ),
        ),
        migrations.AddField(
            model_name="hivmedicationadherence",
            name="meds_shortage_reason",
            field=models.ManyToManyField(
                blank=True,
                to="intecomm_lists.medicationshortagereasons",
                verbose_name="Reasons for not having medications (supply/shortage)",
            ),
        ),
        migrations.AddField(
            model_name="htnmedicationadherence",
            name="meds_missed_in_days",
            field=models.IntegerField(
                blank=True,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(180),
                ],
                verbose_name="Since we last saw you, for how many days did you miss taking your medication",
            ),
        ),
        migrations.AddField(
            model_name="htnmedicationadherence",
            name="meds_shortage_in_days",
            field=models.IntegerField(
                blank=True,
                help_text="That is, your supply of medication was finished",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(180),
                ],
                verbose_name="Since we last saw you, for how many days did you NOT HAVE medication to take",
            ),
        ),
        migrations.AddField(
            model_name="htnmedicationadherence",
            name="meds_shortage_reason",
            field=models.ManyToManyField(
                blank=True,
                to="intecomm_lists.medicationshortagereasons",
                verbose_name="Reasons for not having medications (supply/shortage)",
            ),
        ),
    ]



from __future__ import annotations

from django.contrib import admin
from django_audit_fields.admin import audit_fieldset_tuple
from edc_crf.admin import crf_status_fieldset_tuple

from ..admin_site import intecomm_subject_admin
from ..forms import SocialHarmsForm
from ..models import SocialHarms
from .modeladmin_mixins import CrfModelAdmin


def get_impact_fieldset(prefix: str, phrase: str, description: bool | None = None):
    fields = [f"{prefix}_impact"]
    if description:
        fields.append(f"{prefix}_impact_description")
    fields.extend(
        [
            f"{prefix}_impact_severity",
            f"{prefix}_impact_status",
            f"{prefix}_impact_help",
            f"{prefix}_impact_referal",
        ]
    )
    fields = tuple(fields)
    return (
        f"Impacts of participation on relationships: {prefix.upper()}",
        {
            "description": (
                f"Has participation in the study had a negative impact on {phrase}"
            ),
            "fields": fields,
        },
    )


@admin.register(SocialHarms, site=intecomm_subject_admin)
class SocialHarmsAdmin(CrfModelAdmin):
    form = SocialHarmsForm

    fieldsets = (
        (None, {"fields": ("subject_visit", "report_datetime")}),
        (
            "Disclosure",
            {
                "description": (
                    "Who knows about your participation in the study and how did "
                    "they find out?"
                ),
                "fields": (
                    "partner",
                    "partner_disclosure",
                    "family",
                    "family_disclosure",
                    "friends",
                    "friends_disclosure",
                    "coworkers",
                    "coworkers_disclosure",
                ),
            },
        ),
        get_impact_fieldset("partner", "your relationship with your partner"),
        get_impact_fieldset("family", "your relationship with your family"),
        get_impact_fieldset("friends", "your relationship with your friends"),
        get_impact_fieldset("coworkers", "your relationship with your co-workers"),
        get_impact_fieldset("healthcare", "your access to healthcare services"),
        get_impact_fieldset(
            "other_service", "your access to any other health services", description=True
        ),
        get_impact_fieldset("employment", "your employment"),
        get_impact_fieldset("insurance", "your health insurance"),
        get_impact_fieldset("other", "any other aspect of your life", description=True),
        crf_status_fieldset_tuple,
        audit_fieldset_tuple,
    )

    radio_fields = {
        "crf_status": admin.VERTICAL,
        "partner": admin.VERTICAL,
        "partner_disclosure": admin.VERTICAL,
        "family": admin.VERTICAL,
        "family_disclosure": admin.VERTICAL,
        "friends": admin.VERTICAL,
        "friends_disclosure": admin.VERTICAL,
        "coworkers": admin.VERTICAL,
        "coworkers_disclosure": admin.VERTICAL,
        "partner_impact": admin.VERTICAL,
        "partner_impact_severity": admin.VERTICAL,
        "partner_impact_status": admin.VERTICAL,
        "partner_impact_help": admin.VERTICAL,
        "partner_impact_referal": admin.VERTICAL,
        "family_impact": admin.VERTICAL,
        "family_impact_severity": admin.VERTICAL,
        "family_impact_status": admin.VERTICAL,
        "family_impact_help": admin.VERTICAL,
        "family_impact_referal": admin.VERTICAL,
        "friends_impact": admin.VERTICAL,
        "friends_impact_severity": admin.VERTICAL,
        "friends_impact_status": admin.VERTICAL,
        "friends_impact_help": admin.VERTICAL,
        "friends_impact_referal": admin.VERTICAL,
        "coworkers_impact": admin.VERTICAL,
        "coworkers_impact_severity": admin.VERTICAL,
        "coworkers_impact_status": admin.VERTICAL,
        "coworkers_impact_help": admin.VERTICAL,
        "coworkers_impact_referal": admin.VERTICAL,
        "healthcare_impact": admin.VERTICAL,
        "healthcare_impact_severity": admin.VERTICAL,
        "healthcare_impact_status": admin.VERTICAL,
        "healthcare_impact_help": admin.VERTICAL,
        "healthcare_impact_referal": admin.VERTICAL,
        "other_service_impact": admin.VERTICAL,
        "other_service_impact_severity": admin.VERTICAL,
        "other_service_impact_status": admin.VERTICAL,
        "other_service_impact_help": admin.VERTICAL,
        "other_service_impact_referal": admin.VERTICAL,
        "employment_impact": admin.VERTICAL,
        "employment_impact_severity": admin.VERTICAL,
        "employment_impact_status": admin.VERTICAL,
        "employment_impact_help": admin.VERTICAL,
        "employment_impact_referal": admin.VERTICAL,
        "insurance_impact": admin.VERTICAL,
        "insurance_impact_severity": admin.VERTICAL,
        "insurance_impact_status": admin.VERTICAL,
        "insurance_impact_help": admin.VERTICAL,
        "insurance_impact_referal": admin.VERTICAL,
        "other_impact": admin.VERTICAL,
        "other_impact_severity": admin.VERTICAL,
        "other_impact_status": admin.VERTICAL,
        "other_impact_help": admin.VERTICAL,
        "other_impact_referal": admin.VERTICAL,
    }



# Generated by Django 4.1.2 on 2022-11-22 15:12

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_group", "0005_patientfollowupcall_historicalpatientfollowupcall"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicalpatientgroup",
            name="enforce_group_size_min",
        ),
        migrations.RemoveField(
            model_name="historicalpatientgroup",
            name="enforce_ratio",
        ),
        migrations.RemoveField(
            model_name="patientgroup",
            name="enforce_group_size_min",
        ),
        migrations.RemoveField(
            model_name="patientgroup",
            name="enforce_ratio",
        ),
        migrations.AddField(
            model_name="historicalpatientgroup",
            name="bypass_group_ratio",
            field=models.BooleanField(
                default=False,
                help_text="If ticked, you must have consulted with your study coordinator first",
                verbose_name="Bypass 2:1 NCD:HIV ratio",
            ),
        ),
        migrations.AddField(
            model_name="historicalpatientgroup",
            name="bypass_group_size_min",
            field=models.BooleanField(
                default=False,
                help_text="If ticked, you must have consulted with your study coordinator first",
                verbose_name="Bypass group size minimum of 14",
            ),
        ),
        migrations.AddField(
            model_name="patientgroup",
            name="bypass_group_ratio",
            field=models.BooleanField(
                default=False,
                help_text="If ticked, you must have consulted with your study coordinator first",
                verbose_name="Bypass 2:1 NCD:HIV ratio",
            ),
        ),
        migrations.AddField(
            model_name="patientgroup",
            name="bypass_group_size_min",
            field=models.BooleanField(
                default=False,
                help_text="If ticked, you must have consulted with your study coordinator first",
                verbose_name="Bypass group size minimum of 14",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatientgroup",
            name="confirm_randomize_now",
            field=models.CharField(
                blank=True,
                max_length=15,
                null=True,
                verbose_name="If YES, please confirm by typing the word RANDOMIZE here",
            ),
        ),
        migrations.AlterField(
            model_name="patientgroup",
            name="confirm_randomize_now",
            field=models.CharField(
                blank=True,
                max_length=15,
                null=True,
                verbose_name="If YES, please confirm by typing the word RANDOMIZE here",
            ),
        ),
    ]



from django.db import models
from edc_constants.constants import NO
from edc_model.models import BaseUuidModel
from edc_sites.model_mixins import SiteModelMixin
from edc_utils import formatted_date
from edc_utils.date import to_local

from ..model_mixins import PatientCallModelMixin
from .patient_log import PatientLog


class PatientCall(PatientCallModelMixin, SiteModelMixin, BaseUuidModel):
    patient_log = models.ForeignKey(PatientLog, on_delete=models.PROTECT)

    def __str__(self):
        call_again = "Do not call again." if self.call_again == NO else "May call again."
        return f"{formatted_date(to_local(self.report_datetime).date())}. {call_again}"

    def natural_key(self):
        return (self.patient_log,)

    natural_key.dependencies = [
        "sites.Site",
        "intecomm_screening.patientlog",
    ]

    class Meta(BaseUuidModel.Meta):
        verbose_name = "Patient Call"
        verbose_name_plural = "Patient Calls"



# Generated by Django 4.2.4 on 2023-08-30 21:32
import sys

from django.core.exceptions import ObjectDoesNotExist
from django.db import migrations
from django.db.migrations import RunPython
from edc_constants.constants import YES
from edc_utils import get_utcnow


def update_willing_to_screen_for_tz(apps, schema_editor):
    """Update any patientlog instance in a group where
    `willing_to_screen` and `stable` is not YES and the patient
    has already been added to a group.
    """
    patient_group_cls = apps.get_model("intecomm_group.patientgroup")
    for patient_group in patient_group_cls.objects.all().order_by("site__id", "name"):
        total = patient_group.patients.all().count()
        if total > 0:
            n = 0
            for patientlog in patient_group.patients.all():
                try:
                    patientlog.subjectscreening
                except ObjectDoesNotExist:
                    patientlog.willing_to_screen = YES
                    patientlog.stable = YES
                    patientlog.user_modified = "erikvw"
                    patientlog.modified = get_utcnow()
                    patientlog.comment = "[auto-updated] willing_to_screen=YES"
                    patientlog.save()
                    n += 1
            if n > 0:
                sys.stdout.write(
                    f"\nUpdated {patient_group.site.id} {patient_group.name} "
                    f"{patient_group.status} {n}/{total}\n"
                )


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0061_historicalpatientlog_comment_and_more"),
    ]

    operations = [RunPython(update_willing_to_screen_for_tz)]



from django.contrib import admin
from edc_model_admin.mixins import InlineHideOriginalObjectNameMixin, TabularInlineMixin
from edc_rx.modeladmin_mixins import DrugRefillAdminMixin, DrugSupplyInlineMixin

from ..admin_site import intecomm_subject_admin
from ..forms import DrugRefillHtnForm, DrugSupplyHtnForm
from ..models import DrugRefillHtn, DrugSupplyHtn
from .modeladmin_mixins import CrfModelAdmin


class DrugSupplyHtnInline(DrugSupplyInlineMixin, TabularInlineMixin, admin.TabularInline):
    model = DrugSupplyHtn
    form = DrugSupplyHtnForm


@admin.register(DrugRefillHtn, site=intecomm_subject_admin)
class DrugRefillHtnAdmin(
    DrugRefillAdminMixin,
    InlineHideOriginalObjectNameMixin,
    CrfModelAdmin,
):
    form = DrugRefillHtnForm
    inlines = [DrugSupplyHtnInline]

    def get_formset(self, request, obj=None, **kwargs):
        formset = super().get_formset(request, obj=None, **kwargs)
        formset.insert_before_fieldset = self.insert_before_fieldset
        return formset



from django.contrib import admin
from django_audit_fields import ModelAdminAuditFieldsMixin
from edc_sites.admin import SiteModelAdminMixin

from ..forms import PatientCallForm
from ..models import PatientCall


class PatientCallInlineMixin:
    model = PatientCall
    form = PatientCallForm
    extra = 0
    readonly_fields = ["report_datetime"]
    radio_fields = {
        "answered": admin.VERTICAL,
        "respondent": admin.VERTICAL,
        "survival_status": admin.VERTICAL,
        "catchment_area": admin.VERTICAL,
        "call_again": admin.VERTICAL,
    }


class AddPatientCallInline(
    SiteModelAdminMixin,
    ModelAdminAuditFieldsMixin,
    PatientCallInlineMixin,
    admin.StackedInline,
):
    fieldsets = (
        [None, {"fields": ("report_datetime",)}],
        (
            "Details of the call",
            {
                "fields": (
                    "answered",
                    "respondent",
                    "survival_status",
                    "catchment_area",
                    "last_appt_date",
                    "next_appt_date",
                    "call_again",
                    "comment",
                ),
            },
        ),
    )
    verbose_name = "New Call"
    verbose_name_plural = "New Calls"

    def has_change_permission(self, request, obj=None):
        return True

    def get_queryset(self, request):
        return PatientCall.objects.none()


class ViewPatientCallInline(
    SiteModelAdminMixin,
    ModelAdminAuditFieldsMixin,
    PatientCallInlineMixin,
    admin.StackedInline,
):
    fieldsets = (
        (
            "Details of the call",
            {
                "classes": ("collapse",),
                "fields": (
                    "report_datetime",
                    "respondent",
                    "survival_status",
                    "catchment_area",
                    "last_appt_date",
                    "next_appt_date",
                    "comment",
                ),
            },
        ),
    )
    verbose_name = "Past Call"
    verbose_name_plural = "Past Calls"

    def has_add_permission(self, request, obj):
        return False

    def has_change_permission(self, request, obj=None):
        return False



from .subject_consent import SubjectConsent


class SubjectConsentTz(SubjectConsent):
    class Meta(SubjectConsent.Meta):
        proxy = True
        verbose_name = "Subject Consent (Tanzania)"
        verbose_name_plural = "Subject Consents (Tanzania)"



from django.apps import AppConfig as DjangoAppConfig
from django.core.management.color import color_style

style = color_style()


class AppConfig(DjangoAppConfig):
    name = "intecomm_sites"
    default_auto_field = "django.db.models.BigAutoField"
    verbose_name = "INTECOMM: Sites"



from django.utils.translation import gettext_lazy as _
from edc_constants.constants import OTHER

from .constants import HC_III, HC_IV

HEALTH_FACILITY_TYPES = (
    (HC_III, "HC III"),
    (HC_IV, "HC IV"),
)

MISSED_VISIT_REASONS = (
    ("forgot", _("Forgot / Can’t remember being told about appointment")),
    ("family_emergency", _("Family emergency (e.g. funeral) and was away")),
    ("travelling", _("Away travelling/visiting")),
    ("working_schooling", _("Away working/schooling")),
    ("too_sick", _("Too sick or weak to come to the centre")),
    ("lack_of_transport", _("Transportation difficulty")),
    ("NOT_SCHEDULED_FOR_FACILITY", _("Clinic visit not required for facility")),
    (OTHER, _("Other reason (specify below)")),
)



from __future__ import annotations

from django.contrib import admin
from django.db.models import QuerySet
from django_audit_fields import audit_fieldset_tuple
from edc_model_admin.mixins import ModelAdminRedirectAllToChangelistMixin
from edc_sites import site_sites
from intecomm_rando.constants import TANZANIA

from ...admin_site import intecomm_screening_admin
from ...forms import SubjectScreeningForm
from ...models import PatientLog, SubjectScreeningTz
from ..modeladmin_mixins import BaseModelAdminMixin
from .fieldsets import (
    get_bp_fieldset,
    get_demographics_fieldset,
    get_dm_fieldset,
    get_first_fieldset,
    get_health_facility_fieldset,
    get_hiv_fieldset,
    get_htn_fieldset,
    get_location_fieldset,
    get_other_fieldset,
    get_other_history_fieldset,
    get_pregnancy_fieldset,
    get_updates_fieldset,
)
from .modeladmin_mixins import SubjectScreeningModelAdminMixin


@admin.register(SubjectScreeningTz, site=intecomm_screening_admin)
class SubjectScreeningTzAdmin(
    SubjectScreeningModelAdminMixin,
    ModelAdminRedirectAllToChangelistMixin,
    BaseModelAdminMixin,
):
    form = SubjectScreeningForm
    ordering = ("site__id", "-report_datetime")

    # ModelAdminRedirectAllToChangelistMixin
    changelist_url = "intecomm_screening_admin:intecomm_screening_patientlog_changelist"
    add_search_field_name = "patient_log_identifier"
    change_search_field_name = "screening_identifier"

    fieldsets = (
        get_first_fieldset(),
        get_demographics_fieldset(include_pii=True),
        get_health_facility_fieldset(),
        get_hiv_fieldset(),
        get_dm_fieldset(),
        get_htn_fieldset(),
        get_pregnancy_fieldset(),
        get_other_history_fieldset(),
        get_location_fieldset(),
        get_bp_fieldset(),
        get_other_fieldset(),
        get_updates_fieldset(),
        audit_fieldset_tuple,
    )

    search_fields = (
        "patient_log_identifier",
        "screening_identifier",
        "subject_identifier",
        "hospital_identifier__exact",
        "initials__exact",
        "reasons_ineligible",
        "legal_name__exact",
        "familiar_name__exact",
    )

    def patient_log_model_cls(self):
        return PatientLog

    def get_queryset(self, request) -> QuerySet[SubjectScreeningTz]:
        queryset = super().get_queryset(request)
        site_ids = [s.site_id for s in site_sites.get_by_country(TANZANIA, aslist=True)]
        return queryset.filter(site__in=site_ids)



# Generated by Django 4.1.7 on 2023-04-06 19:31

from django.db import migrations, models
import edc_model.validators.date


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0026_rename_dminitialreview_med_start_date_estimated_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="dminitialreview",
            name="rx_init",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="Yes",
                max_length=15,
                verbose_name="Has the patient started None?",
            ),
        ),
        migrations.AddField(
            model_name="dminitialreview",
            name="rx_init_date",
            field=models.DateField(
                blank=True,
                help_text="If possible, provide the exact date here instead of estimating above.",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date started None",
            ),
        ),
        migrations.AddField(
            model_name="historicaldminitialreview",
            name="rx_init",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="Yes",
                max_length=15,
                verbose_name="Has the patient started None?",
            ),
        ),
        migrations.AddField(
            model_name="historicaldminitialreview",
            name="rx_init_calculated_date",
            field=models.DateField(
                editable=False,
                help_text="Calculated based on response to `rx_init_ago`",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Estimated date started None",
            ),
        ),
        migrations.AddField(
            model_name="historicaldminitialreview",
            name="rx_init_date",
            field=models.DateField(
                blank=True,
                help_text="If possible, provide the exact date here instead of estimating above.",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date started None",
            ),
        ),
        migrations.AddField(
            model_name="historicalhtninitialreview",
            name="rx_init",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="Yes",
                max_length=15,
                verbose_name="Has the patient started medicines for hypertension?",
            ),
        ),
        migrations.AddField(
            model_name="historicalhtninitialreview",
            name="rx_init_date_is_estimated",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="N/A",
                editable=False,
                max_length=15,
                verbose_name="Was medicines for hypertension start date estimated?",
            ),
        ),
        migrations.AddField(
            model_name="htninitialreview",
            name="rx_init",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="Yes",
                max_length=15,
                verbose_name="Has the patient started medicines for hypertension?",
            ),
        ),
        migrations.AddField(
            model_name="htninitialreview",
            name="rx_init_date_is_estimated",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="N/A",
                editable=False,
                max_length=15,
                verbose_name="Was medicines for hypertension start date estimated?",
            ),
        ),
        migrations.AlterField(
            model_name="dminitialreview",
            name="dx_calculated_date",
            field=models.DateField(
                editable=False,
                help_text="Calculated based on response to `dxdx_ago`",
                null=True,
                verbose_name="Estimated diagnosis date",
            ),
        ),
        migrations.AlterField(
            model_name="dminitialreview",
            name="dx_date_is_estimated",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="N/A",
                editable=False,
                max_length=15,
                verbose_name="Was the diagnosis date estimated?",
            ),
        ),
        migrations.AlterField(
            model_name="dminitialreview",
            name="rx_init_calculated_date",
            field=models.DateField(
                editable=False,
                help_text="Calculated based on response to `rx_init_ago`",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Estimated date started None",
            ),
        ),
        migrations.AlterField(
            model_name="dminitialreview",
            name="rx_init_date_is_estimated",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="N/A",
                editable=False,
                max_length=15,
                verbose_name="Was None start date estimated?",
            ),
        ),
        migrations.AlterField(
            model_name="dminitialreview",
            name="singleton_field",
            field=models.CharField(
                editable=False,
                help_text="auto updated for unique constraint",
                max_length=50,
                null=True,
                unique=True,
                verbose_name="subject identifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldminitialreview",
            name="dx_calculated_date",
            field=models.DateField(
                editable=False,
                help_text="Calculated based on response to `dxdx_ago`",
                null=True,
                verbose_name="Estimated diagnosis date",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldminitialreview",
            name="dx_date_is_estimated",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="N/A",
                editable=False,
                max_length=15,
                verbose_name="Was the diagnosis date estimated?",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldminitialreview",
            name="rx_init_date_is_estimated",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="N/A",
                editable=False,
                max_length=15,
                verbose_name="Was None start date estimated?",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldminitialreview",
            name="singleton_field",
            field=models.CharField(
                db_index=True,
                editable=False,
                help_text="auto updated for unique constraint",
                max_length=50,
                null=True,
                verbose_name="subject identifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhivinitialreview",
            name="dx_calculated_date",
            field=models.DateField(
                editable=False,
                help_text="Calculated based on response to `dxdx_ago`",
                null=True,
                verbose_name="Estimated diagnosis date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhivinitialreview",
            name="dx_date_is_estimated",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="N/A",
                editable=False,
                max_length=15,
                verbose_name="Was the diagnosis date estimated?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhivinitialreview",
            name="rx_init_calculated_date",
            field=models.DateField(
                editable=False,
                help_text="Calculated based on response to `rx_init_ago`",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Estimated date started antiretroviral therapy (ART)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhivinitialreview",
            name="rx_init_date_is_estimated",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="N/A",
                editable=False,
                max_length=15,
                verbose_name="Was antiretroviral therapy (ART) start date estimated?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhivinitialreview",
            name="singleton_field",
            field=models.CharField(
                db_index=True,
                editable=False,
                help_text="auto updated for unique constraint",
                max_length=50,
                null=True,
                verbose_name="subject identifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhtninitialreview",
            name="dx_calculated_date",
            field=models.DateField(
                editable=False,
                help_text="Calculated based on response to `dxdx_ago`",
                null=True,
                verbose_name="Estimated diagnosis date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhtninitialreview",
            name="dx_date_is_estimated",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="N/A",
                editable=False,
                max_length=15,
                verbose_name="Was the diagnosis date estimated?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhtninitialreview",
            name="rx_init_calculated_date",
            field=models.DateField(
                editable=False,
                help_text="Calculated based on response to `rx_init_ago`",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Estimated date started medicines for hypertension",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhtninitialreview",
            name="rx_init_date",
            field=models.DateField(
                blank=True,
                help_text="If possible, provide the exact date here instead of estimating above.",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date started medicines for hypertension",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhtninitialreview",
            name="singleton_field",
            field=models.CharField(
                db_index=True,
                editable=False,
                help_text="auto updated for unique constraint",
                max_length=50,
                null=True,
                verbose_name="subject identifier",
            ),
        ),
        migrations.AlterField(
            model_name="hivinitialreview",
            name="dx_calculated_date",
            field=models.DateField(
                editable=False,
                help_text="Calculated based on response to `dxdx_ago`",
                null=True,
                verbose_name="Estimated diagnosis date",
            ),
        ),
        migrations.AlterField(
            model_name="hivinitialreview",
            name="dx_date_is_estimated",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="N/A",
                editable=False,
                max_length=15,
                verbose_name="Was the diagnosis date estimated?",
            ),
        ),
        migrations.AlterField(
            model_name="hivinitialreview",
            name="rx_init_calculated_date",
            field=models.DateField(
                editable=False,
                help_text="Calculated based on response to `rx_init_ago`",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Estimated date started antiretroviral therapy (ART)",
            ),
        ),
        migrations.AlterField(
            model_name="hivinitialreview",
            name="rx_init_date_is_estimated",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="N/A",
                editable=False,
                max_length=15,
                verbose_name="Was antiretroviral therapy (ART) start date estimated?",
            ),
        ),
        migrations.AlterField(
            model_name="hivinitialreview",
            name="singleton_field",
            field=models.CharField(
                editable=False,
                help_text="auto updated for unique constraint",
                max_length=50,
                null=True,
                unique=True,
                verbose_name="subject identifier",
            ),
        ),
        migrations.AlterField(
            model_name="htninitialreview",
            name="dx_calculated_date",
            field=models.DateField(
                editable=False,
                help_text="Calculated based on response to `dxdx_ago`",
                null=True,
                verbose_name="Estimated diagnosis date",
            ),
        ),
        migrations.AlterField(
            model_name="htninitialreview",
            name="dx_date_is_estimated",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="N/A",
                editable=False,
                max_length=15,
                verbose_name="Was the diagnosis date estimated?",
            ),
        ),
        migrations.AlterField(
            model_name="htninitialreview",
            name="rx_init_calculated_date",
            field=models.DateField(
                editable=False,
                help_text="Calculated based on response to `rx_init_ago`",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Estimated date started medicines for hypertension",
            ),
        ),
        migrations.AlterField(
            model_name="htninitialreview",
            name="rx_init_date",
            field=models.DateField(
                blank=True,
                help_text="If possible, provide the exact date here instead of estimating above.",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date started medicines for hypertension",
            ),
        ),
        migrations.AlterField(
            model_name="htninitialreview",
            name="singleton_field",
            field=models.CharField(
                editable=False,
                help_text="auto updated for unique constraint",
                max_length=50,
                null=True,
                unique=True,
                verbose_name="subject identifier",
            ),
        ),
    ]



from django.contrib import admin
from django_audit_fields import audit_fieldset_tuple
from edc_qol.modeladmin_mixins import icecapa_fieldsets, icecapa_radio_fields

from ..admin_site import intecomm_subject_admin
from ..forms import IcecapaForm
from ..models import Icecapa
from .modeladmin_mixins import CrfModelAdmin


@admin.register(Icecapa, site=intecomm_subject_admin)
class IcecapaModelAdmin(CrfModelAdmin):
    form = IcecapaForm

    fieldsets = (
        (None, {"fields": ("subject_visit", "report_datetime")}),
        *icecapa_fieldsets(),
        audit_fieldset_tuple,
    )

    radio_fields = icecapa_radio_fields()



# Generated by Django 4.2.3 on 2023-07-26 13:25

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_lists", "0006_consentrefusalreasons_screeningrefusalreasons_and_more"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("sites", "0002_alter_domain_unique"),
        # ("intecomm_facility", "0002_alter_healthfacility_device_created_and_more"),
        (
            "intecomm_screening",
            "0047_rename_historicalhealthfacility_historicaloldhealthfacility_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="healthtalklog",
            name="old_health_facility",
            field=models.CharField(max_length=100, null=True),
        ),
        migrations.AlterField(
            model_name="historicalhealthtalklog",
            name="old_health_facility",
            field=models.CharField(max_length=100, null=True),
        ),
        migrations.AlterField(
            model_name="idenfifierformat",
            name="old_health_facility",
            field=models.CharField(max_length=100, null=True),
        ),
    ]



from __future__ import annotations

from django.apps import apps as django_apps
from django.core.exceptions import ObjectDoesNotExist
from django.db.models.signals import m2m_changed, post_save
from django.dispatch import receiver
from edc_constants.constants import MULTI_MORBIDITY
from edc_dx import get_diagnosis_labels_prefixes
from intecomm_form_validators import RECRUITING

from ..utils import PatientGroupRatioError, verify_patient_group_ratio_raise
from .patient_group_appointment import PatientGroupAppointment
from .patient_group_meeting import PatientGroupMeeting


@receiver(
    post_save,
    weak=False,
    dispatch_uid="update_patientgroup_on_post_save",
)
def update_patientgroup_on_post_save(sender, instance, raw, update_fields, **kwargs):
    """Check ratio.

    Careful, this will fire before the m2m signal so may not be working with
    up-to-date patient_log instances.
    """
    if (
        not raw
        and not update_fields
        and instance._meta.label_lower.split(".")[1] == "patientgroup"
    ):
        try:
            _, _, ratio = verify_patient_group_ratio_raise(
                instance.patients.all(), raise_on_outofrange=True
            )
        except PatientGroupRatioError:
            if not instance.bypass_group_ratio:
                instance.status = RECRUITING
            _, _, ratio = verify_patient_group_ratio_raise(
                instance.patients.all(), raise_on_outofrange=False
            )
        instance.ratio = ratio
        instance.save_base(update_fields=["ratio", "status"])


@receiver(
    m2m_changed,
    weak=False,
    dispatch_uid="update_patientgroup_patients_from_patientlog_m2ms_on_m2m_changed",
)
def update_patientgroup_patients_from_patientlog_m2ms_on_m2m_changed(
    action, instance, sender, model, pk_set, **kwargs
):
    if model._meta.label_lower == "intecomm_screening.patientlog":
        label_lower = sender._meta.label_lower
        patient_log_cls = django_apps.get_model("intecomm_screening.patientlog")
        conditions = get_diagnosis_labels_prefixes()
        conditions.append(MULTI_MORBIDITY)
        dirty = False
        if action == "post_add":
            for cond in conditions:
                if label_lower == f"intecomm_group.patientgroup_{cond.lower()}_patients":
                    objs = [
                        patient for patient in patient_log_cls.objects.filter(pk__in=pk_set)
                    ]
                    instance.patients.add(*objs)
                    dirty = True
        elif action == "post_remove":
            for cond in conditions:
                if label_lower == f"intecomm_group.patientgroup_{cond.lower()}_patients":
                    objs = [
                        patient for patient in patient_log_cls.objects.filter(pk__in=pk_set)
                    ]
                    instance.patients.remove(*objs)
                    dirty = True
        if dirty:
            instance.status = RECRUITING
            _, _, ratio = verify_patient_group_ratio_raise(
                instance.patients.all(), raise_on_outofrange=False
            )
            instance.ratio = ratio
            instance.save_base(update_fields=["ratio", "status"])


@receiver(
    post_save,
    dispatch_uid="create_or_update_refills_on_post_save",
    sender=PatientGroupAppointment,
)
def create_or_update_patientgroup_meeting_on_post_save(
    sender, instance, raw, created, update_fields, **kwargs
):
    if not raw:
        try:
            PatientGroupMeeting.objects.get(patient_group_appointment=instance)
        except ObjectDoesNotExist:
            PatientGroupMeeting.objects.create(
                patient_group_appointment=instance,
            )



from __future__ import annotations

from edc_appointment.model_mixins import NextAppointmentCrfModelMixin
from edc_model.models import BaseUuidModel

from ..model_mixins import CrfModelMixin


class NextAppointment(NextAppointmentCrfModelMixin, CrfModelMixin, BaseUuidModel):
    class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = "Next Appointment"
        verbose_name_plural = "Next Appointments"
        indexes = CrfModelMixin.Meta.indexes + BaseUuidModel.Meta.indexes



# Generated by Django 4.1.7 on 2023-04-21 20:37

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0035_alter_drugrefilldm_return_in_days_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="dminitialreview",
            name="rx_init",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="Yes",
                max_length=15,
                verbose_name="Has the patient started medicines for diabetes?",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldminitialreview",
            name="rx_init",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="Yes",
                max_length=15,
                verbose_name="Has the patient started medicines for diabetes?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhivinitialreview",
            name="rx_init",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="Yes",
                max_length=15,
                verbose_name="Has the patient started antiretroviral therapy (ART)?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhtninitialreview",
            name="rx_init",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="Yes",
                max_length=15,
                verbose_name="Has the patient started medicines for hypertension?",
            ),
        ),
        migrations.AlterField(
            model_name="hivinitialreview",
            name="rx_init",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="Yes",
                max_length=15,
                verbose_name="Has the patient started antiretroviral therapy (ART)?",
            ),
        ),
        migrations.AlterField(
            model_name="htninitialreview",
            name="rx_init",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="Yes",
                max_length=15,
                verbose_name="Has the patient started medicines for hypertension?",
            ),
        ),
    ]



from __future__ import annotations

from typing import TYPE_CHECKING

from django.apps import apps as django_apps
from django.contrib import admin
from django_audit_fields import audit_fieldset_tuple
from edc_model_admin.history import SimpleHistoryAdmin
from edc_sites import site_sites
from intecomm_rando.constants import TANZANIA

from ..admin_site import intecomm_consent_admin
from ..forms import SubjectConsentTzForm
from ..models import SubjectConsentTz
from .fieldsets import (
    get_first_fieldset,
    get_group_fieldset,
    get_review_questions_fieldset,
)
from .modeladmin_mixins import SubjectConsentModelAdminMixin

if TYPE_CHECKING:
    from django.db.models import QuerySet


__all__ = ["SubjectConsentTzAdmin"]


@admin.register(SubjectConsentTz, site=intecomm_consent_admin)
class SubjectConsentTzAdmin(
    SubjectConsentModelAdminMixin,
    SimpleHistoryAdmin,
):
    form = SubjectConsentTzForm

    fieldsets = (
        get_first_fieldset(include_pii=True),
        get_review_questions_fieldset(),
        get_group_fieldset(),
        audit_fieldset_tuple,
    )

    search_fields = (
        "subject_identifier",
        "screening_identifier",
        "identity__exact",
        "initials__exact",
        "legal_name__exact",
        "familiar_name__exact",
    )

    @property
    def subject_screening_model_cls(self):
        return django_apps.get_model("intecomm_screening.subjectscreening")

    def get_queryset(self, request) -> QuerySet[SubjectConsentTz]:
        queryset = super().get_queryset(request)
        site_ids = [s.site_id for s in site_sites.get_by_country(TANZANIA, aslist=True)]
        return queryset.filter(site__in=site_ids)



from __future__ import annotations

from typing import TYPE_CHECKING, Tuple, Type

from django.contrib import admin
from django.core.exceptions import ObjectDoesNotExist
from edc_consent.actions import (
    flag_as_verified_against_paper,
    unflag_as_verified_against_paper,
)
from edc_consent.modeladmin_mixins import ConsentModelAdminMixin
from edc_constants.choices import GENDER
from edc_model_admin.dashboard import ModelAdminSubjectDashboardMixin
from edc_sites.admin import SiteModelAdminMixin

from intecomm_screening.admin.modeladmin_mixins import (
    InitialDataModelAdminMixin,
    RedirectAllToPatientLogModelAdminMixin,
)

if TYPE_CHECKING:
    from intecomm_screening.models import SubjectScreeningTz, SubjectScreeningUg


class SubjectConsentModelAdminMixin(
    SiteModelAdminMixin,
    InitialDataModelAdminMixin,
    RedirectAllToPatientLogModelAdminMixin,
    ConsentModelAdminMixin,
    ModelAdminSubjectDashboardMixin,
):
    list_per_page = 5

    show_object_tools = False
    show_cancel = True
    change_list_template: str = "intecomm_consent/admin/subjectconsent_change_list.html"
    name_fields: list[str] = ["legal_name", "familiar_name"]
    name_display_field: str = "familiar_name"

    actions = [
        flag_as_verified_against_paper,
        unflag_as_verified_against_paper,
    ]

    radio_fields = {
        "gender": admin.VERTICAL,
        "assessment_score": admin.VERTICAL,
        "consent_copy": admin.VERTICAL,
        "consent_reviewed": admin.VERTICAL,
        "consent_signature": admin.VERTICAL,
        "is_dob_estimated": admin.VERTICAL,
        "identity_type": admin.VERTICAL,
        "is_incarcerated": admin.VERTICAL,
        "is_literate": admin.VERTICAL,
        "language": admin.VERTICAL,
        "study_questions": admin.VERTICAL,
    }

    @property
    def subject_screening_model_cls(self) -> Type[SubjectScreeningTz, SubjectScreeningUg]:
        pass

    def formfield_for_choice_field(self, db_field, request, **kwargs):
        if db_field.name == "gender":
            kwargs["choices"] = GENDER
        return super().formfield_for_choice_field(db_field, request, **kwargs)

    def get_readonly_fields(self, request, obj=None) -> Tuple[str, ...]:
        readonly_fields = super().get_readonly_fields(request, obj=obj)
        if "group_identifier" not in readonly_fields:
            readonly_fields += ("group_identifier",)
        return readonly_fields

    def get_changeform_initial_data(self, request) -> dict:
        dct = super().get_changeform_initial_data(request)
        try:
            subject_screening = self.subject_screening_model_cls.objects.get(
                screening_identifier=dct.get("screening_identifier")
            )
        except ObjectDoesNotExist:
            pass
        else:
            dct.update(**self.initial_form_data(request, subject_screening))
            try:
                identity = dct["hospital_identifier"]
            except KeyError:
                pass
            else:
                dct["identity"] = identity
        return dct



import datetime as dt
import os
from zoneinfo import ZoneInfo

import time_machine
from dateutil.relativedelta import relativedelta
from django.conf import settings
from django.contrib.sites.models import Site
from django.test import TestCase, override_settings
from edc_appointment.constants import INCOMPLETE_APPT, ONTIME_APPT, SKIPPED_APPT
from edc_appointment.models import Appointment, AppointmentType
from edc_constants.constants import COMMUNITY, COMPLETE, HTN, NOT_APPLICABLE
from edc_pharmacy.constants import IN_PROGRESS_APPT
from edc_randomization.site_randomizers import site_randomizers
from edc_timepoint.constants import OPEN_TIMEPOINT
from edc_utils import get_utcnow
from edc_visit_tracking.constants import SCHEDULED
from intecomm_rando.constants import COMMUNITY_ARM, FACILITY_ARM
from intecomm_rando.randomizers import Randomizer
from intecomm_rando.utils import get_assignment_for_subject

from intecomm_screening.tests.intecomm_test_case_mixin import IntecommTestCaseMixin
from intecomm_subject.admin.appointment_admin import AppointmentForm
from intecomm_subject.models import SubjectVisit

utc_tz = ZoneInfo("UTC")


@override_settings(
    EDC_RANDOMIZATION_LIST_PATH=os.path.join(
        settings.BASE_DIR, "intecomm_subject", "tests", "etc", "community_only"
    )
)
@time_machine.travel(dt.datetime(2019, 5, 11, 8, 00, tzinfo=utc_tz))
class TestAppointmentCommunityArm(IntecommTestCaseMixin, TestCase):
    patient_group = None
    import_randomization_list = False
    sid_count_for_tests = 2

    @classmethod
    def setUpTestData(cls):
        super().setUpTestData()
        site_randomizers._registry = {}
        Randomizer.randomizationlist_folder = settings.EDC_RANDOMIZATION_LIST_PATH
        site_randomizers.register(Randomizer)
        randomizer_cls = site_randomizers.get("default")
        randomizer_cls.import_list(verbose=False, sid_count_for_tests=cls.sid_count_for_tests)
        cls.patient_group = cls.get_randomized_patient_group(
            report_datetime=get_utcnow() - relativedelta(days=10), group_name="BRANDX"
        )

    def setUp(self):
        self.assertTrue(self.patient_group.randomized)
        patient_log = self.patient_group.patients.filter(conditions__name__in=[HTN]).first()
        self.subject_identifier = patient_log.subject_identifier

    def update_appt_1000(self):
        appointment = Appointment.objects.get(
            subject_identifier=self.subject_identifier, visit_code="1000"
        )
        SubjectVisit.objects.create(
            appointment=appointment,
            report_datetime=appointment.appt_datetime,
            reason=SCHEDULED,
        )
        appointment.appt_status = INCOMPLETE_APPT
        appointment.save()
        appointment.refresh_from_db()

    @staticmethod
    def get_default_appt_data(appointment):
        return dict(
            subject_identifier=appointment.subject_identifier,
            timepoint=appointment.timepoint,
            timepoint_datetime=appointment.timepoint_datetime,
            timepoint_status=OPEN_TIMEPOINT,
            visit_code=appointment.visit_code,
            visit_code_sequence=appointment.visit_code_sequence,
            facility_name=appointment.facility_name,
            document_status=COMPLETE,
            appt_close_datetime=appointment.appt_datetime,
            appt_datetime=appointment.appt_datetime,
            appt_reason=appointment.appt_reason,
            appt_timing=ONTIME_APPT,
            appt_type=AppointmentType.objects.get(name=COMMUNITY),
            appt_status=IN_PROGRESS_APPT,
            site=Site.objects.get(id=settings.SITE_ID),
        )

    @time_machine.travel(dt.datetime(2019, 5, 11, 8, 00, tzinfo=utc_tz))
    def test_ok(self):
        self.update_appt_1000()
        appointment = Appointment.objects.get(
            subject_identifier=self.subject_identifier, visit_code="1010"
        )
        traveller = time_machine.travel(appointment.appt_datetime + relativedelta(days=3))
        traveller.start()
        self.assertEqual(
            get_assignment_for_subject(appointment.subject_identifier), COMMUNITY_ARM
        )
        data = self.get_default_appt_data(appointment)
        form = AppointmentForm(data=data, instance=appointment)
        form.is_valid()
        self.assertEqual({}, form._errors)

    @time_machine.travel(dt.datetime(2019, 5, 11, 8, 00, tzinfo=utc_tz))
    def test_appt_may_not_be_skipped_in_community_arm(self):
        self.update_appt_1000()
        appointment = Appointment.objects.get(
            subject_identifier=self.subject_identifier, visit_code="1010"
        )
        traveller = time_machine.travel(appointment.appt_datetime + relativedelta(days=3))
        traveller.start()
        self.assertEqual(
            get_assignment_for_subject(appointment.subject_identifier), COMMUNITY_ARM
        )

        data = self.get_default_appt_data(appointment)
        data.update(
            appt_status=SKIPPED_APPT,
            appt_type=AppointmentType.objects.get(name=NOT_APPLICABLE),
            appt_timing=NOT_APPLICABLE,
        )
        form = AppointmentForm(data=data, instance=appointment)
        form.is_valid()
        self.assertIn("appt_status", form._errors)
        self.assertIn(
            "Community appointments may not be skipped", str(form._errors.get("appt_status"))
        )


@override_settings(
    EDC_RANDOMIZATION_LIST_PATH=os.path.join(
        settings.BASE_DIR, "intecomm_subject", "tests", "etc", "facility_only"
    ),
    EDC_RANDOMIZATION_REGISTER_DEFAULT_RANDOMIZER=False,
)
@time_machine.travel(dt.datetime(2019, 5, 11, 8, 00, tzinfo=utc_tz))
class TestAppointmentFacilityArm(IntecommTestCaseMixin, TestCase):
    patient_group = None
    import_randomization_list = False
    sid_count_for_tests = 2

    @classmethod
    def setUpTestData(cls):
        super().setUpTestData()
        site_randomizers._registry = {}
        Randomizer.randomizationlist_folder = settings.EDC_RANDOMIZATION_LIST_PATH
        site_randomizers.register(Randomizer)
        randomizer_cls = site_randomizers.get("default")
        randomizer_cls.import_list(verbose=False, sid_count_for_tests=cls.sid_count_for_tests)
        cls.patient_group = cls.get_randomized_patient_group(
            report_datetime=get_utcnow() - relativedelta(days=10), group_name="BRANDX"
        )

    def setUp(self):
        self.assertTrue(self.patient_group.randomized)
        patient_log = self.patient_group.patients.filter(conditions__name__in=[HTN]).first()
        self.subject_identifier = patient_log.subject_identifier

    def update_appt_1000(self):
        appointment = Appointment.objects.get(
            subject_identifier=self.subject_identifier, visit_code="1000"
        )
        SubjectVisit.objects.create(
            appointment=appointment,
            report_datetime=appointment.appt_datetime,
            reason=SCHEDULED,
        )
        appointment.appt_status = INCOMPLETE_APPT
        appointment.save()
        appointment.refresh_from_db()

    @staticmethod
    def get_default_appt_data(appointment):
        return dict(
            subject_identifier=appointment.subject_identifier,
            timepoint=appointment.timepoint,
            timepoint_datetime=appointment.timepoint_datetime,
            timepoint_status=OPEN_TIMEPOINT,
            visit_code=appointment.visit_code,
            visit_code_sequence=appointment.visit_code_sequence,
            facility_name=appointment.facility_name,
            document_status=COMPLETE,
            appt_close_datetime=appointment.appt_datetime,
            appt_datetime=appointment.appt_datetime,
            appt_reason=appointment.appt_reason,
            appt_timing=ONTIME_APPT,
            appt_type=AppointmentType.objects.get(name=COMMUNITY),
            appt_status=IN_PROGRESS_APPT,
            site=Site.objects.get(id=settings.SITE_ID),
        )

    @time_machine.travel(dt.datetime(2019, 5, 11, 8, 00, tzinfo=utc_tz))
    def test_appt_may_not_be_in_community_for_facility_arm(self):
        self.update_appt_1000()
        appointment = Appointment.objects.get(
            subject_identifier=self.subject_identifier, visit_code="1010"
        )
        self.assertEqual(
            get_assignment_for_subject(appointment.subject_identifier), FACILITY_ARM
        )
        traveller = time_machine.travel(appointment.appt_datetime + relativedelta(days=3))
        traveller.start()

        data = self.get_default_appt_data(appointment)
        data.update(
            appt_status=IN_PROGRESS_APPT,
            appt_type=AppointmentType.objects.get(name=COMMUNITY),
        )
        form = AppointmentForm(data=data, instance=appointment)
        form.is_valid()
        self.assertIn("appt_type", form._errors)
        self.assertIn(
            " A facility-based participant may not attend in the community",
            str(form._errors.get("appt_type")),
        )

    @time_machine.travel(dt.datetime(2019, 5, 11, 8, 00, tzinfo=utc_tz))
    def test_appt_may_be_skipped_in_facility_arm2(self):
        self.update_appt_1000()
        appointment = Appointment.objects.get(
            subject_identifier=self.subject_identifier, visit_code="1010"
        )
        self.assertEqual(
            get_assignment_for_subject(appointment.subject_identifier), FACILITY_ARM
        )
        traveller = time_machine.travel(appointment.appt_datetime + relativedelta(days=3))
        traveller.start()

        data = self.get_default_appt_data(appointment)
        data.update(
            appt_status=SKIPPED_APPT,
            appt_type=AppointmentType.objects.get(name=NOT_APPLICABLE),
            appt_timing=NOT_APPLICABLE,
        )
        form = AppointmentForm(data=data, instance=appointment)
        form.is_valid()
        self.assertEqual({}, form._errors)



from __future__ import annotations

from django.contrib import admin
from django_audit_fields.admin import audit_fieldset_tuple
from edc_crf.admin import crf_status_fieldset_tuple

from ..admin_site import intecomm_subject_admin
from ..forms import HivInitialReviewForm
from ..models import HivInitialReview
from .modeladmin_mixins import CrfModelAdmin


@admin.register(HivInitialReview, site=intecomm_subject_admin)
class HivInitialReviewAdmin(CrfModelAdmin):
    form = HivInitialReviewForm

    fieldsets = (
        (None, {"fields": ("subject_visit", "report_datetime")}),
        (
            "Diagnosis and Care",
            {
                "fields": (
                    "dx_date",
                    "dx_ago",
                    "receives_care",
                    "clinic",
                    "clinic_other",
                )
            },
        ),
        (
            "Monitoring and Treatment",
            {
                "fields": (
                    "rx_init",
                    "rx_init_date",
                    "rx_init_ago",
                    "has_vl",
                    "drawn_date",
                    "vl",
                    "vl_quantifier",
                    "has_cd4",
                    "cd4",
                    "cd4_date",
                ),
            },
        ),
        crf_status_fieldset_tuple,
        audit_fieldset_tuple,
    )

    radio_fields = {
        "rx_init": admin.VERTICAL,
        "clinic": admin.VERTICAL,
        "crf_status": admin.VERTICAL,
        "has_cd4": admin.VERTICAL,
        "has_vl": admin.VERTICAL,
        "receives_care": admin.VERTICAL,
        "vl_quantifier": admin.VERTICAL,
    }

    def get_list_filter(self, request) -> tuple[str, ...]:
        list_filters = super().get_list_filter(request)
        list_filters = list(list_filters) or []
        list_filters.insert(4, "has_vl")
        return tuple(list_filters)

    def get_form(self, request, obj=None, **kwargs):
        form = super().get_form(request, obj=obj, **kwargs)
        form = self.replace_label_text(form, "diagnosis_label", self.model.diagnosis_label)
        return form



from django.contrib import admin
from edc_adverse_event.modeladmin_mixins import AeFollowupModelAdminMixin
from edc_model_admin.history import SimpleHistoryAdmin
from edc_sites.admin import SiteModelAdminMixin

from ..admin_site import intecomm_ae_admin
from ..forms import AeFollowupForm
from ..models import AeFollowup


@admin.register(AeFollowup, site=intecomm_ae_admin)
class AeFollowupAdmin(SiteModelAdminMixin, AeFollowupModelAdminMixin, SimpleHistoryAdmin):
    form = AeFollowupForm

    # TODO: remove with Django > 4.2.5
    def get_list_filter(self, request) -> tuple[str]:
        list_filter = super().get_list_filter(request)
        self.list_filter = list_filter
        return list_filter



# Generated by Django 4.2.1 on 2023-05-23 23:00

from django.db import migrations
import edc_model_fields.fields.other_charfield


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0042_alter_bloodresultsins_fasting_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="healtheconomicshouseholdhead",
            name="relationship_to_hoh_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If OTHER relationship, specify ...",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="relationship_to_hoh_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If OTHER relationship, specify ...",
            ),
        ),
    ]



# Generated by Django 4.2.3 on 2023-08-03 14:26
from django.db import migrations
from tqdm import tqdm


def update_external_wall_material(apps, schema_editor):
    assets_cls = apps.get_model("intecomm_subject.healtheconomicsassets")
    total = assets_cls.objects.all().count()
    for obj in tqdm(assets_cls.objects.all(), total=total):
        if obj.external_wall_material == "4":
            obj.external_wall_material = "5"
            obj.save_base(update_fields=["external_wall_material"])


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0079_auto_20230803_0634"),
    ]

    operations = [migrations.RunPython(update_external_wall_material)]



# Generated by Django 4.2.3 on 2023-08-03 01:59
from django.db import migrations
from tqdm import tqdm


def update_ethnicity_on_he(apps, schema_editor):
    list_model_cls = apps.get_model("edc_he.ethnicities")
    healtheconomicspatient_cls = apps.get_model("intecomm_subject.healtheconomicspatient")
    total = healtheconomicspatient_cls.objects.all().count()
    for obj in tqdm(healtheconomicspatient_cls.objects.all(), total=total):
        list_model_obj = list_model_cls.objects.get(name=obj.pat_ethnicity_old)
        obj.pat_ethnicity_id = list_model_obj.id
        obj.save_base(update_fields="pat_ethnicity")


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0074_healtheconomicspatient_pat_ethnicity_and_more"),
    ]

    operations = [migrations.RunPython(update_ethnicity_on_he)]



from edc_visit_schedule.visit import Crf, FormsCollection

crfs_prn = FormsCollection(
    Crf(show_order=105, model="intecomm_subject.clinicalnote"),
    Crf(show_order=215, model="intecomm_subject.bloodresultsfbc"),
    Crf(show_order=225, model="intecomm_subject.bloodresultsglu"),
    Crf(show_order=235, model="intecomm_subject.bloodresultshba1c"),
    Crf(show_order=245, model="intecomm_subject.bloodresultsrft"),
    Crf(show_order=255, model="intecomm_subject.bloodresultslft"),
    Crf(show_order=265, model="intecomm_subject.bloodresultslipid"),
    Crf(show_order=285, model="intecomm_subject.malariatest"),
    Crf(show_order=295, model="intecomm_subject.urinedipsticktest"),
    Crf(show_order=365, model="intecomm_subject.concomitantmedication"),
    Crf(show_order=385, model="intecomm_subject.urinepregnancy"),
    Crf(show_order=455, model="intecomm_subject.viralloadresult"),
    name="prn",
)

crfs_d1 = FormsCollection(
    Crf(show_order=100, model="intecomm_subject.clinicalreviewbaseline"),
    Crf(show_order=113, model="intecomm_subject.vitals"),
    Crf(show_order=120, model="intecomm_subject.hivinitialreview", required=False),
    Crf(show_order=130, model="intecomm_subject.dminitialreview", required=False),
    Crf(show_order=140, model="intecomm_subject.htninitialreview", required=False),
    Crf(show_order=143, model="intecomm_subject.medications"),
    Crf(show_order=144, model="intecomm_subject.drugrefillhtn", required=False),
    Crf(show_order=150, model="intecomm_subject.drugrefilldm", required=False),
    Crf(show_order=154, model="intecomm_subject.drugrefillhiv", required=False),
    Crf(show_order=164, model="intecomm_subject.hivmedicationadherence", required=False),
    Crf(show_order=170, model="intecomm_subject.dmmedicationadherence", required=False),
    Crf(show_order=184, model="intecomm_subject.htnmedicationadherence", required=False),
    Crf(show_order=190, model="intecomm_subject.otherbaselinedata"),
    Crf(show_order=194, model="intecomm_subject.complicationsbaseline"),
    Crf(show_order=220, model="intecomm_subject.familyhistory"),
    Crf(show_order=240, model="intecomm_subject.icecapa"),
    Crf(show_order=244, model="intecomm_subject.eq5d3l"),
    Crf(show_order=300, model="intecomm_subject.healtheconomicshouseholdhead"),
    Crf(show_order=310, model="intecomm_subject.healtheconomicspatient"),
    Crf(show_order=320, model="intecomm_subject.healtheconomicsassets"),
    Crf(show_order=330, model="intecomm_subject.healtheconomicsproperty"),
    Crf(show_order=340, model="intecomm_subject.healtheconomicsincome"),
    Crf(show_order=400, model="intecomm_subject.nextappointment"),
    name="day1",
)

crfs_followup = FormsCollection(
    Crf(show_order=110, model="intecomm_subject.clinicalreview"),
    Crf(show_order=112, model="intecomm_subject.locationupdate", required=False),
    Crf(show_order=113, model="intecomm_subject.vitals"),
    Crf(show_order=114, model="intecomm_subject.hivinitialreview", required=False),
    Crf(show_order=115, model="intecomm_subject.dminitialreview", required=False),
    Crf(show_order=116, model="intecomm_subject.htninitialreview", required=False),
    Crf(show_order=131, model="intecomm_subject.hivreview", required=False),
    Crf(show_order=135, model="intecomm_subject.viralloadresult", required=False),
    Crf(show_order=141, model="intecomm_subject.dmreview", required=False),
    Crf(show_order=151, model="intecomm_subject.htnreview", required=False),
    Crf(show_order=154, model="intecomm_subject.medications"),
    Crf(show_order=160, model="intecomm_subject.drugrefillhtn", required=False),
    Crf(show_order=170, model="intecomm_subject.drugrefilldm", required=False),
    Crf(show_order=180, model="intecomm_subject.drugrefillhiv", required=False),
    Crf(show_order=184, model="intecomm_subject.hivmedicationadherence", required=False),
    Crf(show_order=190, model="intecomm_subject.dmmedicationadherence", required=False),
    Crf(show_order=194, model="intecomm_subject.htnmedicationadherence", required=False),
    Crf(show_order=200, model="intecomm_subject.complicationsfollowup", required=False),
    Crf(show_order=220, model="intecomm_subject.familyhistory", required=False),
    Crf(show_order=240, model="intecomm_subject.icecapa"),
    Crf(show_order=244, model="intecomm_subject.eq5d3l"),
    Crf(show_order=300, model="intecomm_subject.healtheconomicshouseholdhead", required=False),
    Crf(show_order=310, model="intecomm_subject.healtheconomicspatient", required=False),
    Crf(show_order=320, model="intecomm_subject.healtheconomicsassets", required=False),
    Crf(show_order=330, model="intecomm_subject.healtheconomicsproperty", required=False),
    Crf(show_order=340, model="intecomm_subject.healtheconomicsincome", required=False),
    Crf(show_order=400, model="intecomm_subject.nextappointment"),
    name="followup",
)


crfs_unscheduled = FormsCollection(
    name="unscheduled",
)

crfs_missed = FormsCollection(
    Crf(show_order=1000, model="intecomm_subject.subjectvisitmissed"),
    name="missed",
)



from .consent_refusal import ConsentRefusal
from .health_talk_log import HealthTalkLog
from .patient_call import PatientCall
from .patient_log import PatientLog
from .patient_log_report_print_history import PatientLogReportPrintHistory
from .patient_log_ug import PatientLogUg
from .proxy_models import PatientGroup, PatientGroupRando, Site
from .signals import (
    patient_call_on_post_delete,
    patientlog_on_pre_delete,
    patientlogug_on_pre_delete,
    subjectscreening_on_pre_delete,
    subjectscreeningtz_on_pre_delete,
    subjectscreeningug_on_pre_delete,
    update_patient_call_on_post_save,
    update_subjectscreening_on_post_delete,
    update_subjectscreening_on_post_save,
    update_subjectscreening_post_delete,
    update_subjectscreeningtz_on_post_delete,
    update_subjectscreeningtz_on_post_save,
    update_subjectscreeningug_on_post_delete,
    update_subjectscreeningug_on_post_save,
)
from .subject_screening import SubjectScreening
from .subject_screening_tz import SubjectScreeningTz
from .subject_screening_ug import SubjectScreeningUg



from intecomm_consent.consents import cdef_ug_v1

from .subject_screening import SubjectScreening


class SubjectScreeningUg(SubjectScreening):
    consent_definition = cdef_ug_v1

    class Meta:
        proxy = True
        verbose_name = "Subject Screening (Uganda)"
        verbose_name_plural = "Subject Screening (Uganda)"



from django import forms
from edc_model.widgets import SliderWidget
from intecomm_form_validators.subject import HtnMedicationAdherenceFormValidator

from ..models import HtnMedicationAdherence
from .mixins import CrfModelFormMixin


class HtnMedicationAdherenceForm(CrfModelFormMixin, forms.ModelForm):
    form_validator_cls = HtnMedicationAdherenceFormValidator

    visual_score_slider = forms.CharField(
        label="Visual score for your hypertension medication",
        widget=SliderWidget(attrs={"min": 0, "max": 100}),
    )

    class Meta:
        model = HtnMedicationAdherence
        fields = "__all__"
        labels = {
            "last_missed_pill": (
                "When was the last time you missed taking your hypertension medication?"
            ),
            "missed_pill_reason": (
                "If your hypertension medication was missed, select a reason or reasons"
            ),
        }



# Generated by Django 4.2.3 on 2023-07-25 18:31

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        # ("intecomm_facility", "0002_alter_healthfacility_device_created_and_more"),
        # ("intecomm_screening", "0046_alter_historicalpatientlog_legal_name_and_more"),
        ("intecomm_screening", "0049_healthfacility"),
        ("intecomm_subject", "0063_auto_20230725_2058"),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalnextappointment",
            old_name="health_facility",
            new_name="old_health_facility",
        ),
        migrations.RenameField(
            model_name="nextappointment",
            old_name="health_facility",
            new_name="old_health_facility",
        ),
    ]
